@@ -7,7 +7,6 @@ import numpy as np
 import pandas as pd
 import matplotlib.pylab as plt
 import altair as alt
-from sklearn.utils import deprecated
 from sklearn.preprocessing import normalize
 from sklearn.metrics import pairwise_distances
 from sklearn.metrics.pairwise import (
@@ -632,7 +631,10 @@ class EmbeddingSet:
         mat2 = np.array([w.vector for w in other[overlap]])
         return (
             pd.DataFrame(
-                {"name": overlap, "movement": paired_distances(mat1, mat2, metric)}
+                {
+                    "name": overlap,
+                    "movement": paired_distances(mat1, mat2, metric=metric),
+                }
             )
             .sort_values(["movement"], ascending=False)
             .reset_index()
@@ -773,7 +775,7 @@ class EmbeddingSet:
 
         words = ["prince", "princess", "nurse", "doctor", "banker", "man", "woman",
                  "cousin", "neice", "king", "queen", "dude", "guy", "gal", "fire",
-                 "dog", "cat", "mouse", "red", "bluee", "green", "yellow", "water",
+                 "dog", "cat", "mouse", "red", "blue", "green", "yellow", "water",
                  "person", "family", "brother", "sister"]
 
         lang = SpacyLanguage("en_core_web_sm")
@@ -1018,7 +1020,7 @@ class EmbeddingSet:
 
         words = ["prince", "princess", "nurse", "doctor", "banker", "man", "woman",
                  "cousin", "neice", "king", "queen", "dude", "guy", "gal", "fire",
-                 "dog", "cat", "mouse", "red", "bluee", "green", "yellow", "water",
+                 "dog", "cat", "mouse", "red", "blue", "green", "yellow", "water",
                  "person", "family", "brother", "sister"]
 
         lang = SpacyLanguage("en_core_web_sm")
@@ -1110,7 +1112,7 @@ class EmbeddingSet:
 
         words = ["prince", "princess", "nurse", "doctor", "banker", "man", "woman",
                  "cousin", "neice", "king", "queen", "dude", "guy", "gal", "fire",
-                 "dog", "cat", "mouse", "red", "bluee", "green", "yellow", "water",
+                 "dog", "cat", "mouse", "red", "blue", "green", "yellow", "water",
                  "person", "family", "brother", "sister"]
 
         lang = SpacyLanguage("en_core_web_sm")
@@ -1204,6 +1206,7 @@ class EmbeddingSet:
         annot: bool = False,
         color: Union[None, str] = None,
         n_show: int = 15,
+        interactive: bool = False,
     ):
         """
         Makes an interactive plot with a brush element.
@@ -1224,6 +1227,7 @@ class EmbeddingSet:
             annot: drawn points should be annotated
             color: a property that will be used for plotting
             n_show: number of points to show in text selection
+            interactive: turn on/off the zoom/panning feature; if turned on, zoom/pan can be triggered when shift key is held
 
         **Usage**
 
@@ -1272,7 +1276,7 @@ class EmbeddingSet:
             y_lab = y_axis.name
         x_label = x_label if x_label is not None else x_lab
         y_label = y_label if y_label is not None else y_lab
-        title = title if title is not None else f"Click and Drag Here"
+        title = title if title is not None else "Click and Drag Here"
 
         plot_df = pd.DataFrame(
             {
@@ -1313,12 +1317,18 @@ class EmbeddingSet:
             )
             result = result + text
 
-        brush = alt.selection(type="interval")
+        brush = alt.selection_interval(
+            on="[mousedown[!event.shiftKey], mouseup] > mousemove",
+            translate="[mousedown[!event.shiftKey], mouseup] > mousemove!",
+        )
 
         ranked_text = (
             alt.Chart(plot_df)
             .mark_text()
-            .encode(y=alt.Y("row_number:O", axis=None))
+            .encode(
+                y=alt.Y("row_number:O", axis=None),
+                color=alt.Color(":N", legend=None) if not color else alt.Color(color),
+            )
             .transform_window(row_number="row_number()")
             .transform_filter(brush)
             .transform_window(rank="rank(row_number)")
@@ -1329,7 +1339,17 @@ class EmbeddingSet:
             width=250, title="Text Selection"
         )
 
-        return result.add_selection(brush) | text_plt
+        if interactive:
+            zoom = alt.selection_interval(
+                bind="scales",
+                on="[mousedown[event.shiftKey], mouseup] > mousemove",
+                translate="[mousedown[event.shiftKey], mouseup] > mousemove!",
+            )
+            result = result.add_selection(zoom, brush)
+        else:
+            result = result.add_selection(brush)
+
+        return result | text_plt
 
     def plot_interactive_matrix(
         self,
@@ -1362,7 +1382,7 @@ class EmbeddingSet:
 
         words = ["prince", "princess", "nurse", "doctor", "banker", "man", "woman",
                  "cousin", "neice", "king", "queen", "dude", "guy", "gal", "fire",
-                 "dog", "cat", "mouse", "red", "bluee", "green", "yellow", "water",
+                 "dog", "cat", "mouse", "red", "blue", "green", "yellow", "water",
                  "person", "family", "brother", "sister"]
 
         lang = SpacyLanguage("en_core_web_sm")
