@@ -21,7 +21,7 @@ class Pca(SklearnTransformer):
 
     words = ["prince", "princess", "nurse", "doctor", "banker", "man", "woman",
              "cousin", "neice", "king", "queen", "dude", "guy", "gal", "fire",
-             "dog", "cat", "mouse", "red", "bluee", "green", "yellow", "water",
+             "dog", "cat", "mouse", "red", "blue", "green", "yellow", "water",
              "person", "family", "brother", "sister"]
 
     lang = SpacyLanguage("en_core_web_md")
